from botPlus.botPlus import yellow
from botPlus.botPlus import green
from botPlus.botPlus import red
from botPlus.botPlus import bot
